EXTERN_VAR coeffs coeffs1,coeffs2;
BOOLEAN gInitChar(coeffs r, void* p);
